@@ -1,11 +1,32 @@
 """This module contains the main part of Instant, the build_module function."""
 
+# Copyright (C) 2008-2013 Kent-Andre Mardal
+# Copyright (C) 2008-2013 Martin Sandve Alnes
+# Copyright (C) 2009-2014 Johan Hake
+# Copyright (C) 2009 Ilmar Wilbers
+#
+# This file is part of Instant.
+#
+# Instant is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Instant is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Instant. If not, see <http://www.gnu.org/licenses/>.
+#
+# Alternatively, Instant may be distributed under the terms of the BSD license.
+
 import os, sys, shutil, glob, errno
 from itertools import chain
 
 # TODO: Import only the official interface
 from output import *
-from config import header_and_libs_from_pkgconfig, get_swig_version
 from paths import *
 from signatures import *
 from cache import *
@@ -88,13 +109,6 @@ def recompile(modulename, module_path, new_compilation_checksum,
         if old_compilation_checksum == new_compilation_checksum:
             return
 
-    # Verify that SWIG is on the system
-    try:
-        get_swig_version()
-    except OSError:
-        instant_error("In instant.recompile: Could not find swig!"\
-            " You can download swig from http://www.swig.org")
-
     # Create log file for logging of compilation errors
     compile_log_filename = os.path.join(module_path, "compile.log")
     compile_log_filename_dest = os.path.join(get_default_error_dir(), \
@@ -178,7 +192,8 @@ def copy_to_cache(module_path, cache_dir, modulename, \
 
         # Validate the path
         cache_module_path = os.path.join(cache_dir, modulename)
-        if check_for_existing_path and os.path.exists(cache_module_path):
+        if check_for_existing_path and os.path.exists(os.path.join(\
+            cache_module_path, "finished_copying")):
             # This indicates a race condition has happened (and is being avoided!).
             instant_warning("In instant.build_module: Path '%s' already exists,"\
                 " but module wasn't found in cache previously. Not overwriting,"\
@@ -198,9 +213,11 @@ def copy_to_cache(module_path, cache_dir, modulename, \
         instant_debug("In instant.build_module: Copying built module from %r"\
             " to cache at %r" % (module_path, cache_module_path))
         
-        # Do the copying
+        # Do the copying and mark that we are finished by creating an empty file
+        # finished_copying
         try:
             shutil.copytree(module_path, cache_module_path)
+            open(os.path.join(cache_module_path, "finished_copying"), "w")
         except OSError, e:
             if e.errno != errno.EEXIST:
                 raise
@@ -546,14 +563,9 @@ def build_module(modulename=None, source_directory=".",
         # Copy compiled module to cache
         if use_cache:
             module_path = copy_to_cache(module_path, cache_dir, modulename)
-            with file_lock(cache_dir, modulename) as lock:
 
-                # Import module and place in memory cache
-                module = import_and_cache_module(module_path, modulename, moduleids)
-        else:
-
-            # Import module and place in memory cache
-            module = import_and_cache_module(module_path, modulename, moduleids)
+        # Import module and place in memory cache
+        module = import_and_cache_module(module_path, modulename, moduleids)
             
         if not module:
             instant_error("Failed to import newly compiled module!")
@@ -594,10 +606,8 @@ def build_module_vtk(c_code, cache_dir=None):
     module_path = copy_to_cache(module_path, cache_dir, modulename)
 
     os.chdir(original_path)
-    lock = get_lock(cache_dir, modulename)
 
     module = import_and_cache_module(module_path, modulename, moduleids)
-    release_lock(lock)
 
     return module
 
@@ -622,9 +632,7 @@ def build_module_vmtk(c_code, cache_dir=None):
     module_path = copy_to_cache(module_path, cache_dir, modulename)
 
     os.chdir(original_path)
-    lock = get_lock(cache_dir, modulename)
 
     module = import_and_cache_module(module_path, modulename, moduleids)
-    release_lock(lock)
 
     return module
