@@ -16,5 +16,5 @@ from test3_ext import sum
 a = 3.7
 b = 4.8
 c = sum(a,b)
-print "The sum of %g and %g is %g" % (a,b,c) 
+print("The sum of %g and %g is %g" % (a,b,c)) 
 
