@@ -23,19 +23,19 @@ sum = Sum()
 a = 3.7
 b = 4.8
 c = use_Sum(sum,a,b)
-print "The sum of %g and %g is %g"% (a,b,c) 
+print("The sum of %g and %g is %g"% (a,b,c)) 
 
 class Sub(Sum): 
   def __init__(self): 
     Sum.__init__(self) 
     
   def sum(self,a,b): 
-    print "sub" 
+    print("sub") 
     return a-b; 
 
 sub = Sub()
 a = 3.7
 b = 4.8
 c = use_Sum(sub,a,b)
-print "The sub of %g and %g is %g"% (a,b,c) 
+print("The sub of %g and %g is %g"% (a,b,c)) 
 
